@@ -2,7 +2,7 @@
 //
 // ui.h extension file, included from the uic-generated form implementation.
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -185,6 +185,7 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 
     // What style do we create these forms?
 	WFlags wflags = Qt::WStyle_Customize
+		| Qt::WStyle_NormalBorder
 		| Qt::WStyle_Title
 		| Qt::WStyle_SysMenu
 		| Qt::WStyle_MinMax
@@ -287,6 +288,8 @@ bool qjackctlMainForm::setup ( qjackctlSetup *pSetup )
 		m_pPatchbayForm->setRecentPatchbays(m_pSetup->patchbays);
 	 	if (!m_pSetup->sPatchbayPath.isEmpty())
 			m_pPatchbayForm->loadPatchbayFile(m_pSetup->sPatchbayPath);
+		m_pPatchbayForm->updateRecentPatchbays();
+		m_pPatchbayForm->stabilizeForm();
 	}
 	
     // Try to find if we can start in detached mode (client-only)
@@ -646,20 +649,25 @@ void qjackctlMainForm::startJack (void)
             m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
     }
 	else if (bCoreaudio) {
-		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
+		if (m_preset.iInChannels > 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
 			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
-		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
+		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
 			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
 	}
 	else if (bFreebob) {
-		if (m_preset.iInChannels >= 0  && m_preset.iAudio != QJACKCTL_PLAYBACK)
-			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
-		else
-			m_pJack->addArgument("-i0");
-		if (m_preset.iOutChannels >= 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
-			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
-		else
-			m_pJack->addArgument("-o0");
+        switch (m_preset.iAudio) {
+          case QJACKCTL_DUPLEX:
+            m_pJack->addArgument("-D");
+            break;
+          case QJACKCTL_CAPTURE:
+            m_pJack->addArgument("-C");
+            m_pJack->addArgument("-o0");
+            break;
+          case QJACKCTL_PLAYBACK:
+            m_pJack->addArgument("-P");
+            m_pJack->addArgument("-i0");
+            break;
+        }
 	}
     if (bDummy && m_preset.iWait > 0 && m_preset.iWait != 21333)
         m_pJack->addArgument("-w" + QString::number(m_preset.iWait));
@@ -1058,7 +1066,7 @@ void qjackctlMainForm::updateTimeDisplayFonts (void)
     if (!m_pSetup->sDisplayFont2.isEmpty() && font.fromString(m_pSetup->sDisplayFont2)) {
         ServerStateTextLabel->setFont(font);
         ServerModeTextLabel->setFont(font);
-        CpuLoadTextLabel->setFont(font);
+        DspLoadTextLabel->setFont(font);
         SampleRateTextLabel->setFont(font);
         XrunCountTextLabel->setFont(font);
         TransportStateTextLabel->setFont(font);
@@ -1766,7 +1774,7 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
     // All displays are highlighted from now on.
     ServerStateTextLabel->setPaletteForegroundColor(Qt::yellow);
     ServerModeTextLabel->setPaletteForegroundColor(Qt::darkYellow);
-    CpuLoadTextLabel->setPaletteForegroundColor(Qt::yellow);
+    DspLoadTextLabel->setPaletteForegroundColor(Qt::yellow);
     SampleRateTextLabel->setPaletteForegroundColor(Qt::darkYellow);
     TimeDisplayTextLabel->setPaletteForegroundColor(Qt::green);
     TransportStateTextLabel->setPaletteForegroundColor(Qt::green);
@@ -1831,7 +1839,7 @@ void qjackctlMainForm::stopJackClient (void)
 
     // Displays are dimmed again.
     ServerModeTextLabel->setPaletteForegroundColor(Qt::darkYellow);
-    CpuLoadTextLabel->setPaletteForegroundColor(Qt::darkYellow);
+    DspLoadTextLabel->setPaletteForegroundColor(Qt::darkYellow);
     SampleRateTextLabel->setPaletteForegroundColor(Qt::darkYellow);
     TimeDisplayTextLabel->setPaletteForegroundColor(Qt::darkGreen);
     TransportStateTextLabel->setPaletteForegroundColor(Qt::darkGreen);
@@ -2206,7 +2214,7 @@ void qjackctlMainForm::refreshStatus (void)
         // Less frequent status items update...
         if (m_iStatusRefresh >= QJACKCTL_STATUS_CYCLE) {
             m_iStatusRefresh = 0;
-            updateStatusItem(STATUS_CPU_LOAD, QString::number(jack_cpu_load(m_pJackClient), 'g', 2) + s + "%");
+            updateStatusItem(STATUS_DSP_LOAD, QString::number(jack_cpu_load(m_pJackClient), 'g', 2) + s + "%");
             updateStatusItem(STATUS_SAMPLE_RATE, QString::number(jack_get_sample_rate(m_pJackClient)) + s + tr("Hz"));
             updateStatusItem(STATUS_BUFFER_SIZE, QString::number(g_nframes) + " " + tr("frames"));
 #ifdef CONFIG_JACK_REALTIME
@@ -2271,7 +2279,7 @@ void qjackctlMainForm::refreshStatus (void)
     }   // No need to update often if we're just idle...
     else if (m_iStatusRefresh >= QJACKCTL_STATUS_CYCLE) {
         m_iStatusRefresh = 0;
-        updateStatusItem(STATUS_CPU_LOAD, n);
+        updateStatusItem(STATUS_DSP_LOAD, n);
         updateStatusItem(STATUS_SAMPLE_RATE, n);
         updateStatusItem(STATUS_BUFFER_SIZE, n);
         updateStatusItem(STATUS_REALTIME, n);
@@ -2299,8 +2307,8 @@ void qjackctlMainForm::updateStatusItem( int iStatusItem, const QString& sText )
       case STATUS_SERVER_STATE:
         ServerStateTextLabel->setText(sText);
         break;
-      case STATUS_CPU_LOAD:
-        CpuLoadTextLabel->setText(sText);
+      case STATUS_DSP_LOAD:
+        DspLoadTextLabel->setText(sText);
         break;
       case STATUS_SAMPLE_RATE:
         SampleRateTextLabel->setText(sText);
